@@ -90,10 +90,7 @@ impl Spotify {
         spotify.set_volume(volume, true);
 
         spotify.api.set_worker_channel(spotify.channel.clone());
-        spotify
-            .api
-            .update_token()
-            .map(move |h| ASYNC_RUNTIME.get().unwrap().block_on(h).ok());
+        spotify.api.update_token();
 
         spotify.api.set_user(user);
 
