@@ -275,16 +275,15 @@ impl<I: ListItem + Clone> ListView<I> {
                         let clicked_list_item =
                             content.get(self.selected).map(ListItem::as_listitem);
 
-                        if let Some(target) = clicked_list_item {
-                            if let Some(view) =
+                        if let Some(target) = clicked_list_item
+                            && let Some(view) =
                                 target.open(self.queue.clone(), self.library.clone())
-                            {
-                                return MouseHandleResult::Handled(EventResult::Consumed(Some(
-                                    Callback::from_fn_once(move |s| {
-                                        s.on_layout(|_, mut l| l.push_view(view));
-                                    }),
-                                )));
-                            }
+                        {
+                            return MouseHandleResult::Handled(EventResult::Consumed(Some(
+                                Callback::from_fn_once(move |s| {
+                                    s.on_layout(|_, mut l| l.push_view(view));
+                                }),
+                            )));
                         }
                     }
                 }
@@ -544,15 +543,15 @@ impl<I: ListItem + Clone> ViewExt for ListView<I> {
                     content.get(self.selected).cloned()
                 };
 
-                if let Some(track) = item {
-                    if let Some(track) = track.track() {
-                        let dialog = ContextMenu::add_track_dialog(
-                            self.library.clone(),
-                            self.queue.get_spotify(),
-                            track,
-                        );
-                        return Ok(CommandResult::Modal(Box::new(dialog)));
-                    }
+                if let Some(track) = item
+                    && let Some(track) = track.track()
+                {
+                    let dialog = ContextMenu::add_track_dialog(
+                        self.library.clone(),
+                        self.queue.get_spotify(),
+                        track,
+                    );
+                    return Ok(CommandResult::Modal(Box::new(dialog)));
                 }
 
                 return Ok(CommandResult::Consumed(None));
